@@ -13,8 +13,24 @@ class Application:
         self.uiAppId = ui
         self.device = d
 
-    def launch(self):
+    def launch(self, timeout=None):
         self.device.con.get(path="launchApp", args="sopid=" + self.sopId + "&" + "uiappid=" + self.uiAppId)
+        if timeout is None:
+            timeout = self.device.default_timeout
+        for m_iter in range(0, timeout):
+            self.device.refresh_layout()
+            selector = etree.XML(self.device.xmlStr.encode('utf-8'))
+            if selector.get("sopId") == self.sopId:
+                return True
+            sleep(1)
+        return False
+
+    def is_topmost(self):
+        self.device.refresh_layout()
+        selector = etree.XML(self.device.xmlStr.encode('utf-8'))
+        if selector.get("sopId") == self.sopId:
+            return True
+        return False
 
     def close(self):
         self.device.con.get(path="quitApp", args="sopid=" + self.sopId)
@@ -22,7 +38,10 @@ class Application:
     def __get_device_default_time(self):
         return self.device.default_timeout
 
-    def find_item_by_xpath(self, xpath_key, timeout=None):
+    def find_item_by_xpath_key(self, xpath_key, timeout=None):
+        return self.find_item_by_xpath(self.device.get_xpath(self.sopId, xpath_key), timeout)
+
+    def find_item_by_xpath(self, xpath, timeout=None):
         if timeout is None:
             timeout = self.device.default_timeout
         for m_iter in range(0, timeout):
@@ -30,11 +49,11 @@ class Application:
                 sleep(1)
             self.device.refresh_layout()
             selector = etree.XML(self.device.xmlStr.encode('utf-8'))
-            nodes = selector.xpath(self.device.get_xpath(self.sopId, xpath_key))
+            nodes = selector.xpath(xpath)
             if selector.get("sopId") == self.sopId:
                 if len(nodes) > 0:
                     node = nodes[0]
-                    i = Item.Item(d=self.device, a=self, node=node, xpath=self.device.get_xpath(self.sopId, xpath_key))
+                    i = Item.Item(d=self.device, a=self, node=node, xpath=xpath)
                     return i
             else:
                 raise Exception('error: application is not the top window!')
