@@ -99,7 +99,7 @@ class Device(Events.Events):
     def screenshot(self, path=__screenshots):
         if not os.path.exists(path):
             os.makedirs(path)
-        img_base64 = str(self.con.get(path="getScreenShot").read(), 'utf-8')
+        img_base64 = str(self.con.get(path="getScreenShot").read(), 'utf-8').split(',')[0]
         current_remote_time = self.con.get(path="getSystemTime").read()
         file_name = str(current_remote_time, 'utf-8') + ".png"
         image = open(path + "/" + file_name, "wb")
